# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'source/typing_window.ui'
#
# Created by: PyQt5 UI code generator 5.15.6
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_typingWindow(object):
    def setupUi(self, typingWindow):
        typingWindow.setObjectName("typingWindow")
        typingWindow.resize(830, 619)
        self.verticalLayout = QtWidgets.QVBoxLayout(typingWindow)
        self.verticalLayout.setObjectName("verticalLayout")
        self.scrollArea = QtWidgets.QScrollArea(typingWindow)
        self.scrollArea.setFocusPolicy(QtCore.Qt.NoFocus)
        self.scrollArea.setWidgetResizable(True)
        self.scrollArea.setObjectName("scrollArea")
        self.scrollAreaWidgetContents = QtWidgets.QWidget()
        self.scrollAreaWidgetContents.setGeometry(QtCore.QRect(0, 0, 810, 599))
        self.scrollAreaWidgetContents.setMinimumSize(QtCore.QSize(800, 500))
        self.scrollAreaWidgetContents.setObjectName("scrollAreaWidgetContents")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(self.scrollAreaWidgetContents)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.lineInput = QtWidgets.QLineEdit(self.scrollAreaWidgetContents)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Fixed)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.lineInput.sizePolicy().hasHeightForWidth())
        self.lineInput.setSizePolicy(sizePolicy)
        self.lineInput.setMinimumSize(QtCore.QSize(0, 0))
        self.lineInput.setMaximumSize(QtCore.QSize(0, 0))
        self.lineInput.setMaxLength(100000)
        self.lineInput.setObjectName("lineInput")
        self.verticalLayout_2.addWidget(self.lineInput)
        spacerItem = QtWidgets.QSpacerItem(0, 17, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        self.verticalLayout_2.addItem(spacerItem)
        self.labelTitle = QtWidgets.QLabel(self.scrollAreaWidgetContents)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.labelTitle.sizePolicy().hasHeightForWidth())
        self.labelTitle.setSizePolicy(sizePolicy)
        self.labelTitle.setMinimumSize(QtCore.QSize(0, 50))
        self.labelTitle.setSizeIncrement(QtCore.QSize(0, 0))
        font = QtGui.QFont()
        font.setFamily("Sans Serif")
        font.setPointSize(28)
        font.setBold(True)
        font.setWeight(75)
        self.labelTitle.setFont(font)
        self.labelTitle.setStyleSheet("")
        self.labelTitle.setAlignment(QtCore.Qt.AlignBottom|QtCore.Qt.AlignHCenter)
        self.labelTitle.setObjectName("labelTitle")
        self.verticalLayout_2.addWidget(self.labelTitle)
        spacerItem1 = QtWidgets.QSpacerItem(20, 20, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_2.addItem(spacerItem1)
        self.labelMainText = QtWidgets.QLabel(self.scrollAreaWidgetContents)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Expanding)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.labelMainText.sizePolicy().hasHeightForWidth())
        self.labelMainText.setSizePolicy(sizePolicy)
        font = QtGui.QFont()
        font.setPointSize(26)
        self.labelMainText.setFont(font)
        self.labelMainText.setStyleSheet("padding: 0 100px; font-size: 26pt;")
        self.labelMainText.setLineWidth(1)
        self.labelMainText.setMidLineWidth(1)
        self.labelMainText.setTextFormat(QtCore.Qt.RichText)
        self.labelMainText.setScaledContents(False)
        self.labelMainText.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.labelMainText.setWordWrap(True)
        self.labelMainText.setIndent(-1)
        self.labelMainText.setTextInteractionFlags(QtCore.Qt.NoTextInteraction)
        self.labelMainText.setObjectName("labelMainText")
        self.verticalLayout_2.addWidget(self.labelMainText)
        spacerItem2 = QtWidgets.QSpacerItem(20, 20, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_2.addItem(spacerItem2)
        self.horizontalLayoutButtons = QtWidgets.QHBoxLayout()
        self.horizontalLayoutButtons.setSizeConstraint(QtWidgets.QLayout.SetFixedSize)
        self.horizontalLayoutButtons.setContentsMargins(-1, 0, -1, -1)
        self.horizontalLayoutButtons.setObjectName("horizontalLayoutButtons")
        spacerItem3 = QtWidgets.QSpacerItem(20, 20, QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayoutButtons.addItem(spacerItem3)
        self.buttonMainMenu = QtWidgets.QPushButton(self.scrollAreaWidgetContents)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.buttonMainMenu.sizePolicy().hasHeightForWidth())
        self.buttonMainMenu.setSizePolicy(sizePolicy)
        self.buttonMainMenu.setMinimumSize(QtCore.QSize(0, 40))
        self.buttonMainMenu.setCursor(QtGui.QCursor(QtCore.Qt.PointingHandCursor))
        self.buttonMainMenu.setFocusPolicy(QtCore.Qt.NoFocus)
        self.buttonMainMenu.setAutoDefault(False)
        self.buttonMainMenu.setDefault(False)
        self.buttonMainMenu.setObjectName("buttonMainMenu")
        self.horizontalLayoutButtons.addWidget(self.buttonMainMenu)
        spacerItem4 = QtWidgets.QSpacerItem(25, 20, QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayoutButtons.addItem(spacerItem4)
        self.buttonRestart = QtWidgets.QPushButton(self.scrollAreaWidgetContents)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.buttonRestart.sizePolicy().hasHeightForWidth())
        self.buttonRestart.setSizePolicy(sizePolicy)
        self.buttonRestart.setCursor(QtGui.QCursor(QtCore.Qt.PointingHandCursor))
        self.buttonRestart.setFocusPolicy(QtCore.Qt.NoFocus)
        self.buttonRestart.setObjectName("buttonRestart")
        self.horizontalLayoutButtons.addWidget(self.buttonRestart)
        spacerItem5 = QtWidgets.QSpacerItem(25, 20, QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayoutButtons.addItem(spacerItem5)
        self.buttonNewText = QtWidgets.QPushButton(self.scrollAreaWidgetContents)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.buttonNewText.sizePolicy().hasHeightForWidth())
        self.buttonNewText.setSizePolicy(sizePolicy)
        self.buttonNewText.setCursor(QtGui.QCursor(QtCore.Qt.PointingHandCursor))
        self.buttonNewText.setFocusPolicy(QtCore.Qt.NoFocus)
        self.buttonNewText.setObjectName("buttonNewText")
        self.horizontalLayoutButtons.addWidget(self.buttonNewText)
        spacerItem6 = QtWidgets.QSpacerItem(80, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayoutButtons.addItem(spacerItem6)
        self.labelTime = QtWidgets.QLabel(self.scrollAreaWidgetContents)
        self.labelTime.setObjectName("labelTime")
        self.horizontalLayoutButtons.addWidget(self.labelTime)
        self.labelUnit = QtWidgets.QLabel(self.scrollAreaWidgetContents)
        self.labelUnit.setObjectName("labelUnit")
        self.horizontalLayoutButtons.addWidget(self.labelUnit)
        spacerItem7 = QtWidgets.QSpacerItem(20, 20, QtWidgets.QSizePolicy.Fixed, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayoutButtons.addItem(spacerItem7)
        self.verticalLayout_2.addLayout(self.horizontalLayoutButtons)
        spacerItem8 = QtWidgets.QSpacerItem(20, 20, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        self.verticalLayout_2.addItem(spacerItem8)
        self.scrollArea.setWidget(self.scrollAreaWidgetContents)
        self.verticalLayout.addWidget(self.scrollArea)

        self.retranslateUi(typingWindow)
        QtCore.QMetaObject.connectSlotsByName(typingWindow)

    def retranslateUi(self, typingWindow):
        _translate = QtCore.QCoreApplication.translate
        typingWindow.setWindowTitle(_translate("typingWindow", "Typing window"))
        self.labelTitle.setText(_translate("typingWindow", "Mode"))
        self.labelMainText.setText(_translate("typingWindow", "Placeholder text: you should not be seeing this :("))
        self.buttonMainMenu.setText(_translate("typingWindow", "Back"))
        self.buttonRestart.setText(_translate("typingWindow", "Restart"))
        self.buttonNewText.setText(_translate("typingWindow", "New Text"))
        self.labelTime.setText(_translate("typingWindow", "1000"))
        self.labelUnit.setText(_translate("typingWindow", "s"))



DARK_MODE = dict(
    base=dict(
        bg="hsl(217, 35%, 17%)",
        bg_lighter="hsl(217, 35%, 25%)",
        text="hsl(0, 0%, 85%)",
        text_button="hsl(0, 0%, 62%)",
    ),
    rich_text=dict(
        green="hsl(124, 70%, 21%)",
        red="hsl(0, 65%, 38%)",
    ),
    graph=dict(
        axes="#d9d9d9",
        curve="#136c19",
    ),
)
LIGHT_MODE = dict(
    base=dict(
        bg="hsl(217, 35%, 84%)",
        bg_lighter="hsl(217, 35%, 94%)",
        text="hsl(0, 0%, 14%)",
        text_button="hsl(0, 0%, 47%)",
    ),
    rich_text=dict(
        green="hsl(124, 60%, 45%)",
        red="hsl(0, 80%, 55%)",
    ),
    graph=dict(
        axes="#000000",
        curve="#1ca025",
    ),
)
SWITCH_COLOURS = dict(
    bg_colour="#9e9e9e",
    circle_colour="#d9d9d9",
    active_bg_colour="#3381ff",
)


# FUNCTIONS -----------------------------------------------------------------------------
def get_colours(is_dark_mode: bool = True) -> dict[str, dict[str, str]]:
    """Returns dictionary of of all colours used for program."""

    return dict(DARK_MODE if is_dark_mode else LIGHT_MODE, switch=SWITCH_COLOURS)


def get_style_sheet(
    bg: str = "", bg_lighter: str = "", text: str = "", text_button: str = ""
) -> str:
    """
    Returns a string representing the style sheet.

    Usage: get_style_sheet(True) for dark mode or get_style_sheet(False) for light mode
    """

    return f"""QWidget {{
            background: {bg};
            color: {text};
            font-size: 24pt;
            font-weight: bold;
            font-family: "Inconsolata Bold";
        }}
        QPushButton, QComboBox {{
            background: transparent;
            font-size: 25pt;
            border-radius: 5;
            padding: 8px;
            text-align: left;
            color: {text_button};
        }}
        QPushButton::hover, QComboBox::hover, QPushButton::focus, QComboBox::focus {{
            background: transparent;
            color: {text};
            outline: none;
        }}
        QComboBox::down-arrow {{
            background: transparent;
        }}
        QComboBox::item {{
            background: {bg_lighter};
        }}
        QComboBox::item:selected {{
            font-weight: bold;
            color: {text};
        }}
        QLabel, QRadioButton, QScrollArea, QScrollBar::add-line:vertical,
        QScrollBar::sub-line:vertical, #graphView {{
            background: transparent;
            border: none;
        }}
        QScrollBar {{
            background: {bg};
        }}
        QScrollBar::handle {{
            background: {text_button};
            border: none;
        }}
        QScrollBar::handle:pressed {{
            background: {text};
        }}
        #labelMainMenu, #labelTitle, #labelStatistics {{
            font-size: 50pt;
        }}
        #labelDaysAgo {{
            color: {text_button}
        }}"""



# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'source/main_menu.ui'
#
# Created by: PyQt5 UI code generator 5.15.6
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_mainMenu(object):
    def setupUi(self, mainMenu):
        mainMenu.setObjectName("mainMenu")
        mainMenu.resize(858, 697)
        mainMenu.setStyleSheet("")
        self.horizontalLayout = QtWidgets.QHBoxLayout(mainMenu)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.scrollArea = QtWidgets.QScrollArea(mainMenu)
        self.scrollArea.setWidgetResizable(True)
        self.scrollArea.setObjectName("scrollArea")
        self.scrollAreaWidgetContents = QtWidgets.QWidget()
        self.scrollAreaWidgetContents.setGeometry(QtCore.QRect(0, 0, 838, 677))
        self.scrollAreaWidgetContents.setMinimumSize(QtCore.QSize(640, 600))
        self.scrollAreaWidgetContents.setObjectName("scrollAreaWidgetContents")
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout(self.scrollAreaWidgetContents)
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem)
        self.verticalLayout_3 = QtWidgets.QVBoxLayout()
        self.verticalLayout_3.setContentsMargins(0, -1, -1, 0)
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        spacerItem1 = QtWidgets.QSpacerItem(20, 10, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_3.addItem(spacerItem1)
        self.labelMainMenu = QtWidgets.QLabel(self.scrollAreaWidgetContents)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.labelMainMenu.sizePolicy().hasHeightForWidth())
        self.labelMainMenu.setSizePolicy(sizePolicy)
        self.labelMainMenu.setMinimumSize(QtCore.QSize(0, 100))
        self.labelMainMenu.setMaximumSize(QtCore.QSize(16777215, 40))
        font = QtGui.QFont()
        font.setPointSize(36)
        font.setBold(False)
        font.setWeight(50)
        self.labelMainMenu.setFont(font)
        self.labelMainMenu.setStyleSheet("")
        self.labelMainMenu.setTextFormat(QtCore.Qt.PlainText)
        self.labelMainMenu.setAlignment(QtCore.Qt.AlignLeading|QtCore.Qt.AlignLeft|QtCore.Qt.AlignVCenter)
        self.labelMainMenu.setObjectName("labelMainMenu")
        self.verticalLayout_3.addWidget(self.labelMainMenu)
        spacerItem2 = QtWidgets.QSpacerItem(20, 50, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        self.verticalLayout_3.addItem(spacerItem2)
        self.buttonStart = QtWidgets.QPushButton(self.scrollAreaWidgetContents)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.buttonStart.sizePolicy().hasHeightForWidth())
        self.buttonStart.setSizePolicy(sizePolicy)
        self.buttonStart.setMinimumSize(QtCore.QSize(0, 40))
        font = QtGui.QFont()
        font.setPointSize(16)
        self.buttonStart.setFont(font)
        self.buttonStart.setCursor(QtGui.QCursor(QtCore.Qt.PointingHandCursor))
        self.buttonStart.setAutoDefault(True)
        self.buttonStart.setObjectName("buttonStart")
        self.verticalLayout_3.addWidget(self.buttonStart)
        spacerItem3 = QtWidgets.QSpacerItem(20, 5, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        self.verticalLayout_3.addItem(spacerItem3)
        self.comboBoxSelectMode = QtWidgets.QComboBox(self.scrollAreaWidgetContents)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.comboBoxSelectMode.sizePolicy().hasHeightForWidth())
        self.comboBoxSelectMode.setSizePolicy(sizePolicy)
        self.comboBoxSelectMode.setMinimumSize(QtCore.QSize(300, 40))
        font = QtGui.QFont()
        font.setPointSize(16)
        self.comboBoxSelectMode.setFont(font)
        self.comboBoxSelectMode.setCursor(QtGui.QCursor(QtCore.Qt.PointingHandCursor))
        self.comboBoxSelectMode.setFocusPolicy(QtCore.Qt.StrongFocus)
        self.comboBoxSelectMode.setSizeAdjustPolicy(QtWidgets.QComboBox.AdjustToContentsOnFirstShow)
        self.comboBoxSelectMode.setIconSize(QtCore.QSize(0, 0))
        self.comboBoxSelectMode.setFrame(False)
        self.comboBoxSelectMode.setObjectName("comboBoxSelectMode")
        self.comboBoxSelectMode.addItem("")
        self.comboBoxSelectMode.addItem("")
        self.comboBoxSelectMode.addItem("")
        self.comboBoxSelectMode.addItem("")
        self.comboBoxSelectMode.addItem("")
        self.comboBoxSelectMode.addItem("")
        self.comboBoxSelectMode.addItem("")
        self.verticalLayout_3.addWidget(self.comboBoxSelectMode)
        spacerItem4 = QtWidgets.QSpacerItem(20, 5, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        self.verticalLayout_3.addItem(spacerItem4)
        self.buttonSettings = QtWidgets.QPushButton(self.scrollAreaWidgetContents)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.buttonSettings.sizePolicy().hasHeightForWidth())
        self.buttonSettings.setSizePolicy(sizePolicy)
        self.buttonSettings.setMinimumSize(QtCore.QSize(0, 40))
        font = QtGui.QFont()
        font.setPointSize(16)
        self.buttonSettings.setFont(font)
        self.buttonSettings.setCursor(QtGui.QCursor(QtCore.Qt.PointingHandCursor))
        self.buttonSettings.setAutoDefault(True)
        self.buttonSettings.setObjectName("buttonSettings")
        self.verticalLayout_3.addWidget(self.buttonSettings)
        spacerItem5 = QtWidgets.QSpacerItem(20, 5, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        self.verticalLayout_3.addItem(spacerItem5)
        self.buttonStatistics = QtWidgets.QPushButton(self.scrollAreaWidgetContents)
        sizePolicy = QtWidgets.QSizePolicy(QtWidgets.QSizePolicy.Preferred, QtWidgets.QSizePolicy.Preferred)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.buttonStatistics.sizePolicy().hasHeightForWidth())
        self.buttonStatistics.setSizePolicy(sizePolicy)
        self.buttonStatistics.setMinimumSize(QtCore.QSize(0, 40))
        font = QtGui.QFont()
        font.setPointSize(16)
        self.buttonStatistics.setFont(font)
        self.buttonStatistics.setCursor(QtGui.QCursor(QtCore.Qt.PointingHandCursor))
        self.buttonStatistics.setAutoDefault(True)
        self.buttonStatistics.setObjectName("buttonStatistics")
        self.verticalLayout_3.addWidget(self.buttonStatistics)
        spacerItem6 = QtWidgets.QSpacerItem(20, 5, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Fixed)
        self.verticalLayout_3.addItem(spacerItem6)
        self.buttonExit = QtWidgets.QPushButton(self.scrollAreaWidgetContents)
        self.buttonExit.setMinimumSize(QtCore.QSize(0, 40))
        font = QtGui.QFont()
        font.setPointSize(16)
        self.buttonExit.setFont(font)
        self.buttonExit.setCursor(QtGui.QCursor(QtCore.Qt.PointingHandCursor))
        self.buttonExit.setAutoDefault(True)
        self.buttonExit.setObjectName("buttonExit")
        self.verticalLayout_3.addWidget(self.buttonExit)
        spacerItem7 = QtWidgets.QSpacerItem(20, 40, QtWidgets.QSizePolicy.Minimum, QtWidgets.QSizePolicy.Expanding)
        self.verticalLayout_3.addItem(spacerItem7)
        self.horizontalLayout_2.addLayout(self.verticalLayout_3)
        spacerItem8 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem8)
        self.scrollArea.setWidget(self.scrollAreaWidgetContents)
        self.horizontalLayout.addWidget(self.scrollArea)

        self.retranslateUi(mainMenu)
        QtCore.QMetaObject.connectSlotsByName(mainMenu)

    def retranslateUi(self, mainMenu):
        _translate = QtCore.QCoreApplication.translate
        mainMenu.setWindowTitle(_translate("mainMenu", "Speed Type Test"))
        self.labelMainMenu.setText(_translate("mainMenu", "Main Menu"))
        self.buttonStart.setText(_translate("mainMenu", "Begin"))
        self.comboBoxSelectMode.setItemText(0, _translate("mainMenu", "Common Phrases"))
        self.comboBoxSelectMode.setItemText(1, _translate("mainMenu", "Facts"))
        self.comboBoxSelectMode.setItemText(2, _translate("mainMenu", "Famous Literature Excerpts"))
        self.comboBoxSelectMode.setItemText(3, _translate("mainMenu", "Famous Quotes"))
        self.comboBoxSelectMode.setItemText(4, _translate("mainMenu", "Random Text: Brown"))
        self.comboBoxSelectMode.setItemText(5, _translate("mainMenu", "Random Text: Gutenberg"))
        self.comboBoxSelectMode.setItemText(6, _translate("mainMenu", "Random Text: Webtext"))
        self.buttonSettings.setText(_translate("mainMenu", "Settings"))
        self.buttonStatistics.setText(_translate("mainMenu", "Statistics"))
        self.buttonExit.setText(_translate("mainMenu", "Exit"))
